summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--docs/gst_plugins_cache.json2
-rw-r--r--gst/rtsp/gstrtspsrc.c4
2 files changed, 3 insertions, 3 deletions
diff --git a/docs/gst_plugins_cache.json b/docs/gst_plugins_cache.json
index a49625295..de369d562 100644
--- a/docs/gst_plugins_cache.json
+++ b/docs/gst_plugins_cache.json
@@ -20776,7 +20776,7 @@
},
{
"name": "arg1",
- "type": "GstBuffer"
+ "type": "GstSample"
}
],
"return-type": "GstFlowReturn",
diff --git a/gst/rtsp/gstrtspsrc.c b/gst/rtsp/gstrtspsrc.c
index 242ef6dbe..21321e879 100644
--- a/gst/rtsp/gstrtspsrc.c
+++ b/gst/rtsp/gstrtspsrc.c
@@ -1131,7 +1131,7 @@ gst_rtspsrc_class_init (GstRTSPSrcClass * klass)
/**
* GstRTSPSrc::push-backchannel-buffer:
* @rtspsrc: a #GstRTSPSrc
* @buffer: RTP buffer to send back
*
*
*/
@@ -1139,7 +1139,7 @@ gst_rtspsrc_class_init (GstRTSPSrcClass * klass)
g_signal_new ("push-backchannel-buffer", G_TYPE_FROM_CLASS (klass),
G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, G_STRUCT_OFFSET (GstRTSPSrcClass,
push_backchannel_buffer), NULL, NULL, NULL,
- GST_TYPE_FLOW_RETURN, 2, G_TYPE_UINT, GST_TYPE_BUFFER);
+ GST_TYPE_FLOW_RETURN, 2, G_TYPE_UINT, GST_TYPE_SAMPLE);
/**
* GstRTSPSrc::get-parameter:
@@ -1131,7 +1131,7 @@ gst_rtspsrc_class_init (GstRTSPSrcClass * klass)
* GstRTSPSrc::push-backchannel-buffer:
* @rtspsrc: a #GstRTSPSrc
- * @buffer: RTP buffer to send back
+ * @sample: RTP sample to send back
*
*